@@ -33,7 +33,7 @@
 """
 
 import sys
-from dbpoolpy.dbhelper.mysql import SimpleMysqlConnection
+from dbpoolpy.dbconnect.simple import SimpleConnection
 
 baseint = int
 
@@ -69,7 +69,7 @@ def connect(
         failures, ping, closeable, *args, **kwargs)
 
 
-class SteadyDBConnection(SimpleMysqlConnection):
+class SteadyDBConnection(SimpleConnection):
     """基于DB-API 2模块的稳定连接。"""
 
     def __init__(
